@@ -16,6 +16,6 @@ def test_get_application_home(tmp_path):
     assert not home
 
     p = tmp_path / settings.ALDRYN_DOT_FILE
-    p.write_text(u"#Examplecontent")
+    p.write_text("#Examplecontent")
     home = utils.get_application_home(str(tmp_path))
     assert home
